import * as chatbot from 'aws-cdk-lib/aws-chatbot';
import { SlackChannelConfigurationProps } from 'aws-cdk-lib/aws-chatbot/lib/slack-channel-configuration';
import { Construct } from 'constructs';
export interface SlackChannel {
    /**
     * The name of Slack channel configuration
     */
    readonly slackChannelConfigurationName: string;
    /**
     * The ID of the Slack workspace authorized with AWS Chatbot.
     *
     * To get the workspace ID, you must perform the initial authorization flow with Slack in the AWS Chatbot console.
     * Then you can copy and paste the workspace ID from the console.
     * For more details, see steps 1-4 in Setting Up AWS Chatbot with Slack in the AWS Chatbot User Guide.
     * @see https://docs.aws.amazon.com/chatbot/latest/adminguide/setting-up.html#Setup_intro
     */
    readonly slackWorkspaceId: string;
    /**
     * The ID of the Slack channel.
     *
     * To get the ID, open Slack, right click on the channel name in the left pane, then choose Copy Link.
     * The channel ID is the 9-character string at the end of the URL. For example, ABCBBLZZZ.
     */
    readonly slackChannelId: string;
}
export declare class AccountChatbots {
    static slackChatBots: Record<string, chatbot.SlackChannelConfiguration>;
    static existsSlackChannel(scope: Construct, chatbotProps: SlackChannel): boolean;
    static addSlackChannel(scope: Construct, id: string, chatbotProps: SlackChannelConfigurationProps): chatbot.SlackChannelConfiguration;
    static findSlackChannel(scope: Construct, chatbotProps: SlackChannel): chatbot.SlackChannelConfiguration;
    private static slackBotId;
}
