import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { IdentitystoreClientResolvedConfig } from "../IdentitystoreClient";
/**
 * @internal
 */
export interface IdentitystoreHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface IdentitystoreHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<IdentitystoreClientResolvedConfig, HandlerExecutionContext, IdentitystoreHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultIdentitystoreHttpAuthSchemeParametersProvider: (config: IdentitystoreClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<IdentitystoreHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface IdentitystoreHttpAuthSchemeProvider extends HttpAuthSchemeProvider<IdentitystoreHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultIdentitystoreHttpAuthSchemeProvider: IdentitystoreHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: IdentitystoreHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: IdentitystoreHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
