import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { DeleteApplicationAssignmentRequest, DeleteApplicationAssignmentResponse } from "../models/models_0";
import { ServiceInputTypes, ServiceOutputTypes, SSOAdminClientResolvedConfig } from "../SSOAdminClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeleteApplicationAssignmentCommand}.
 */
export interface DeleteApplicationAssignmentCommandInput extends DeleteApplicationAssignmentRequest {
}
/**
 * @public
 *
 * The output of {@link DeleteApplicationAssignmentCommand}.
 */
export interface DeleteApplicationAssignmentCommandOutput extends DeleteApplicationAssignmentResponse, __MetadataBearer {
}
declare const DeleteApplicationAssignmentCommand_base: {
    new (input: DeleteApplicationAssignmentCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteApplicationAssignmentCommandInput, DeleteApplicationAssignmentCommandOutput, SSOAdminClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DeleteApplicationAssignmentCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteApplicationAssignmentCommandInput, DeleteApplicationAssignmentCommandOutput, SSOAdminClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Revoke application access to an application by deleting application assignments for a
 *             user or group.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { SSOAdminClient, DeleteApplicationAssignmentCommand } from "@aws-sdk/client-sso-admin"; // ES Modules import
 * // const { SSOAdminClient, DeleteApplicationAssignmentCommand } = require("@aws-sdk/client-sso-admin"); // CommonJS import
 * const client = new SSOAdminClient(config);
 * const input = { // DeleteApplicationAssignmentRequest
 *   ApplicationArn: "STRING_VALUE", // required
 *   PrincipalId: "STRING_VALUE", // required
 *   PrincipalType: "USER" || "GROUP", // required
 * };
 * const command = new DeleteApplicationAssignmentCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param DeleteApplicationAssignmentCommandInput - {@link DeleteApplicationAssignmentCommandInput}
 * @returns {@link DeleteApplicationAssignmentCommandOutput}
 * @see {@link DeleteApplicationAssignmentCommandInput} for command's `input` shape.
 * @see {@link DeleteApplicationAssignmentCommandOutput} for command's `response` shape.
 * @see {@link SSOAdminClientResolvedConfig | config} for SSOAdminClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have sufficient access to perform this action.</p>
 *
 * @throws {@link ConflictException} (client fault)
 *  <p>Occurs when a conflict with a previous successful write is detected. This generally
 *             occurs when the previous write did not have time to propagate to the host serving the
 *             current request. A retry (with appropriate backoff logic) is the recommended response to
 *             this exception.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>The request processing has failed because of an unknown error, exception, or failure
 *             with an internal server.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>Indicates that a requested resource is not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Indicates that the principal has crossed the throttling limits of the API
 *             operations.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>The request failed because it contains a syntax error.</p>
 *
 * @throws {@link SSOAdminServiceException}
 * <p>Base exception class for all service exceptions from SSOAdmin service.</p>
 *
 * @public
 */
export declare class DeleteApplicationAssignmentCommand extends DeleteApplicationAssignmentCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DeleteApplicationAssignmentRequest;
            output: {};
        };
        sdk: {
            input: DeleteApplicationAssignmentCommandInput;
            output: DeleteApplicationAssignmentCommandOutput;
        };
    };
}
