import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ListApplicationsRequest, ListApplicationsResponse } from "../models/models_0";
import { ServiceInputTypes, ServiceOutputTypes, SSOAdminClientResolvedConfig } from "../SSOAdminClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListApplicationsCommand}.
 */
export interface ListApplicationsCommandInput extends ListApplicationsRequest {
}
/**
 * @public
 *
 * The output of {@link ListApplicationsCommand}.
 */
export interface ListApplicationsCommandOutput extends ListApplicationsResponse, __MetadataBearer {
}
declare const ListApplicationsCommand_base: {
    new (input: ListApplicationsCommandInput): import("@smithy/smithy-client").CommandImpl<ListApplicationsCommandInput, ListApplicationsCommandOutput, SSOAdminClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: ListApplicationsCommandInput): import("@smithy/smithy-client").CommandImpl<ListApplicationsCommandInput, ListApplicationsCommandOutput, SSOAdminClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Lists all applications associated with the instance of IAM Identity Center. When listing applications for an instance
 *             in the management account, member accounts must use the <code>applicationAccount</code>
 *             parameter to filter the list to only applications created from that account.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { SSOAdminClient, ListApplicationsCommand } from "@aws-sdk/client-sso-admin"; // ES Modules import
 * // const { SSOAdminClient, ListApplicationsCommand } = require("@aws-sdk/client-sso-admin"); // CommonJS import
 * const client = new SSOAdminClient(config);
 * const input = { // ListApplicationsRequest
 *   InstanceArn: "STRING_VALUE", // required
 *   MaxResults: Number("int"),
 *   NextToken: "STRING_VALUE",
 *   Filter: { // ListApplicationsFilter
 *     ApplicationAccount: "STRING_VALUE",
 *     ApplicationProvider: "STRING_VALUE",
 *   },
 * };
 * const command = new ListApplicationsCommand(input);
 * const response = await client.send(command);
 * // { // ListApplicationsResponse
 * //   Applications: [ // ApplicationList
 * //     { // Application
 * //       ApplicationArn: "STRING_VALUE",
 * //       ApplicationProviderArn: "STRING_VALUE",
 * //       Name: "STRING_VALUE",
 * //       ApplicationAccount: "STRING_VALUE",
 * //       InstanceArn: "STRING_VALUE",
 * //       Status: "ENABLED" || "DISABLED",
 * //       PortalOptions: { // PortalOptions
 * //         SignInOptions: { // SignInOptions
 * //           Origin: "IDENTITY_CENTER" || "APPLICATION", // required
 * //           ApplicationUrl: "STRING_VALUE",
 * //         },
 * //         Visibility: "ENABLED" || "DISABLED",
 * //       },
 * //       Description: "STRING_VALUE",
 * //       CreatedDate: new Date("TIMESTAMP"),
 * //     },
 * //   ],
 * //   NextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListApplicationsCommandInput - {@link ListApplicationsCommandInput}
 * @returns {@link ListApplicationsCommandOutput}
 * @see {@link ListApplicationsCommandInput} for command's `input` shape.
 * @see {@link ListApplicationsCommandOutput} for command's `response` shape.
 * @see {@link SSOAdminClientResolvedConfig | config} for SSOAdminClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have sufficient access to perform this action.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>The request processing has failed because of an unknown error, exception, or failure
 *             with an internal server.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Indicates that the principal has crossed the throttling limits of the API
 *             operations.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>The request failed because it contains a syntax error.</p>
 *
 * @throws {@link SSOAdminServiceException}
 * <p>Base exception class for all service exceptions from SSOAdmin service.</p>
 *
 * @public
 */
export declare class ListApplicationsCommand extends ListApplicationsCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListApplicationsRequest;
            output: ListApplicationsResponse;
        };
        sdk: {
            input: ListApplicationsCommandInput;
            output: ListApplicationsCommandOutput;
        };
    };
}
